@@ -1,11 +1,10 @@
 BOLD = 0x02
 COLOR = 0x03
-ITALIC = 0x09
+ITALIC = 0x1D
 STRIKETHROUGH = 0x13
 RESET = 0x0f
 UNDERLINE = 0x15
-UNDERLINE2 = 0x1f
-REVERSE = 0x16
+MONOSPACE = 0x11
 
 WHITE = 0
 BLACK = 1
